@@ -98,6 +98,12 @@ gis_driver_finalize (GObject *object)
   G_OBJECT_CLASS (gis_driver_parent_class)->finalize (object);
 }
 
+static void
+assistant_page_changed (GtkScrolledWindow *sw)
+{
+  gtk_adjustment_set_value (gtk_scrolled_window_get_vadjustment (sw), 0);
+}
+
 static void
 prepare_main_window (GisDriver *driver)
 {
@@ -112,6 +118,11 @@ prepare_main_window (GisDriver *driver)
   gtk_container_add (GTK_CONTAINER (sw), child);
   g_object_unref (child);
 
+  g_signal_connect_swapped (priv->assistant,
+                            "page-changed",
+                            G_CALLBACK (assistant_page_changed),
+                            sw);
+
   gtk_window_set_titlebar (priv->main_window,
                            gis_assistant_get_titlebar (priv->assistant));
 }
@@ -369,14 +380,14 @@ update_screen_size (GisDriver *driver)
                                       GTK_POLICY_NEVER,
                                       GTK_POLICY_NEVER);
 
-      size_hints.min_width = 1024;
-      size_hints.min_height = 768;
+      size_hints.min_width = size_hints.max_width = 1024;
+      size_hints.min_height = size_hints.max_height = 768;
       size_hints.win_gravity = GDK_GRAVITY_CENTER;
 
       gtk_window_set_geometry_hints (priv->main_window,
                                      NULL,
                                      &size_hints,
-                                     GDK_HINT_MIN_SIZE | GDK_HINT_WIN_GRAVITY);
+                                     GDK_HINT_MIN_SIZE | GDK_HINT_MAX_SIZE | GDK_HINT_WIN_GRAVITY);
       gtk_window_set_resizable (priv->main_window, FALSE);
       gtk_window_set_position (priv->main_window, GTK_WIN_POS_CENTER_ALWAYS);
 
